@@ -13,7 +13,7 @@ our @CARP_NOT = qw(
   Dumbbench::Result
 );
 
-our $VERSION = '0.10_01';
+our $VERSION = '0.04';
 
 require Exporter;
 
@@ -21,7 +21,7 @@ our @ISA = qw(Exporter);
 our @EXPORT = ();
 our @EXPORT_OK = qw(
   timeit timethis timethese cmpthese
-  timediff timestr timesum
+  timediff timestr timesum 
 );
 our %EXPORT_TAGS = (all => [@EXPORT, @EXPORT_OK]);
 
@@ -136,7 +136,7 @@ sub timethese {
 sub cmpthese {
   my $count = shift;
   my $codehashref = shift;
-  my $style = shift || ''; # ignored unless 'none'
+  my $style = shift; # ignored unless 'none'
 
   my $results;
   if (ref($count)) {
@@ -273,7 +273,7 @@ sub timestr {
     $digits = length($1) + 1;
   }
   $rel = sprintf("\%.${digits}f", $rel);
-
+  
   my $rate = $self->_rate_str;
   my $str = "$time +- $err wallclock secs ($rel%) @ ($rate)/s (n=" . $res->nsamples . ")";
 
@@ -308,8 +308,6 @@ sub _rate {
 
 __END__
 
-=encoding utf8
-
 =head1 NAME
 
 Benchmark::Dumb - Benchmark.pm compatibility layer for Dumbbench
@@ -392,7 +390,7 @@ The cache-related functions aren't implemented because we don't use a cache.
 
 The original C<Benchmark.pm> implementation provides a rudimentary
 object-oriented interface. We do not faithfully copy that. See
-L</METHODS> below.
+L<"/METHODS"> below.
 
 =item *
 
@@ -564,7 +562,7 @@ Steffen Mueller, E<lt>smueller@cpan.orgE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2010, 2012 by Steffen Mueller
+Copyright (C) 2010 by Steffen Mueller
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself, either Perl version 5.8.1 or,
